intelmq.bots.collectors.shodan package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.collectors.shodan package

## Submodules

## intelmq.bots.collectors.shodan.collector_stream module

Parameters: * api_key: The API key

Selectors: The only possible selector is currently the country: * countries: A list of strings or a comma separated list with country codes

`intelmq.bots.collectors.shodan.collector_stream.` `BOT`

  alias of `intelmq.bots.collectors.shodan.collector_stream.ShodanStreamCollectorBot`

class `intelmq.bots.collectors.shodan.collector_stream.` `ShodanStreamCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  Collect the Shodan stream from the Shodan API

  `api_key`: str = '<INSERT your API key>'
  `countries`: List[str] = []
  `init`()
  `process`()

## Module contents